# Generated by Django 3.2.5 on 2023-04-04 11:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0015_auto_20230209_1410'),
    ]

    operations = [
        migrations.AddField(
            model_name='ipn',
            name='statement_url',
            field=models.URLField(default='https://nashledger-test.azurewebsites.net/bank_callbacks'),
        ),
    ]
